@@ -209,6 +209,49 @@ impl Unum {
             Err(PyTypeError::new_err("Should be Unitless"))
         }
     }
+
+
+    // --- equality operators ---
+
+    fn __lt__(&self, o: &Unum) -> PyResult<bool> {
+        return if self.unit == o.unit {
+            Ok(self.val < o.val)
+        } else {
+            Err(PyTypeError::new_err("Unit Mismatch"))
+        }
+    }
+
+    fn __le__(&self, o: &Unum) -> PyResult<bool> {
+        return if self.unit == o.unit {
+            Ok(self.val <= o.val)
+        } else {
+            Err(PyTypeError::new_err("Unit Mismatch"))
+        }
+    }
+
+    fn __eq__(&self, o: &Unum) -> PyResult<bool> {
+        return if self.unit == o.unit {
+            Ok(self.val == o.val)
+        } else {
+            Err(PyTypeError::new_err("Unit Mismatch"))
+        }
+    }
+
+    fn __ne__(&self, o: &Unum) -> PyResult<bool> {
+        return if self.unit == o.unit {
+            Ok(self.val != o.val)
+        } else {
+            Err(PyTypeError::new_err("Unit Mismatch"))
+        }
+    }
+
+    fn __ge__(&self, o: &Unum) -> PyResult<bool> {
+        return if self.unit == o.unit {
+            Ok(self.val >= o.val)
+        } else {
+            Err(PyTypeError::new_err("Unit Mismatch"))
+        }
+    }
 }
 
 #[inline]
